<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>文档查看器</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>文档查看器是一款支持PDF、DJVU、DOCX等多种格式的文档阅读工具。</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>主题</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>关键词</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>制作者</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>创建者</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>创建于</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>修改于</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>页数</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>优化</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>页面大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>否</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>添加书签</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>您确定要删除所有书签吗？</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>删除注释</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>添加注释</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>删除书签</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>添加书签</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>高亮</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>取消高亮</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>第一页</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>前一页</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>后一页</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>最后一页</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>左旋转</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>右旋转</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>文档信息</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="141"/>
        <source>Documents</source>
        <translation>文档文件</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>不支持该文件格式</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>打开失败</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>请检查文件是否损坏</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>转换失败，请检查文件是否损坏</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>保存失败</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>保存成功</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>请输入有效的文件名</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>拖拽文件到此</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>支持格式：%1 </translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>选择文件</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
        <source>The bookmark has been removed</source>
        <translation>已删除书签</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
        <source>Please select the text</source>
        <translation>请选择文本</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
        <source>The annotation has been removed</source>
        <translation>已删除注释</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>此文档已加密，请输入密码</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>密码错误</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="125"/>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="133"/>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>选择工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>手形工具</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>添加注释</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>您确定要删除所有注释吗？</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>请输入有效的页码</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>正在转换</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>文档未保存</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation>是否保存对“%1”的编辑？</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>不保存</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>保 存</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>双页显示</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>默认大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>适合页面</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>适应高度</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>适应宽度</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="109"/>
        <source>%1 items found</source>
        <translation>%1个搜索结果</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>文档正在尝试链接至：</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>如果信任该网站，请点击“允许”，否则请选择“阻止”。</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>阻止</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>允许</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>缩略图</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>注释</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="58"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="79"/>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Display</source>
        <translation>视图</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page up</source>
        <translation>上一页</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page down</source>
        <translation>下一页</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom in</source>
        <translation>页面放大</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom out</source>
        <translation>页面缩小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <source>Zoom in/Zoom out</source>
        <translation>页面放大/缩小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Thumbnails</source>
        <translation>打开目录缩略图</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>1:1 size</source>
        <translation>默认大小</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit height</source>
        <translation>适应高度</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit width</source>
        <translation>适应宽度</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate left</source>
        <translation>左旋转</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate right</source>
        <translation>右旋转</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Select text</source>
        <translation>选择工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Hand tool</source>
        <translation>手形工具</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add bookmark</source>
        <translation>添加书签</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Magnifier</source>
        <translation>放大镜</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add annotation</source>
        <translation>添加注释</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Highlight</source>
        <translation>高亮</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>删除注释</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>删除书签</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>第%1页</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>新窗口</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>新标签页</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>放大镜</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>缩略图</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>输入已达上限</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Document File Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>FilePath</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>ThumbnailPath Path.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Generate thumbnail.</translation>
    </message>
</context>
</TS>
